__version__ = "0.0.13"

from .value_counts_plus import value_counts_plus
from .status_codes import status_codes
from .url_structure import url_structure
from .racing_chart import racing_chart
from .flag import flag, country_code_flag
from .style_table import style_table